<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ko_KR">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>1개 이상의 장치 선택</translation>
    </message>
</context>
<context>
    <name>QvkAudioController_wl</name>
    <message>
        <source>Select one or more devices</source>
        <translation>1개 이상의 장치 선택</translation>
    </message>
</context>
<context>
    <name>QvkCameraSingle</name>
    <message>
        <source>Remove window frame</source>
        <translation>창틀 제거</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>상하 뒤집기</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>좌우 뒤집기</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>반전</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>회색</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>흑백</translation>
    </message>
    <message>
        <source>Switch to Window</source>
        <translation>창으로 전환</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>전체화면 전환</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Camera</source>
        <translation>카메라</translation>
    </message>
</context>
<context>
    <name>QvkCiscoFinishDialog</name>
    <message>
        <source>The setup was successful.</source>
        <translation>설치를 성공적으로 마쳤습니다.</translation>
    </message>
    <message>
        <source>Close this window and start vokoscreenNG again.</source>
        <translation>이 창을 닫고 vokoscreenNG를 다시 시작해 주세요.</translation>
    </message>
    <message>
        <source>Have fun with vokoscreenNG</source>
        <translation>vovkoscreenNG로 즐겨보세요</translation>
    </message>
</context>
<context>
    <name>QvkDirDialog</name>
    <message>
        <source>Dialog</source>
        <translation>대화창</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>도움말</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>파일탐색기가 없습니다.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>파일탐색기를 설치해 주세요.</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs_wl</name>
    <message>
        <source>No filemanager found.</source>
        <translation>파일탐색기가 없습니다.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>파일탐색기를 설치해 주세요.</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>경고</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>디스크 여유 공간이 충분하지 않아서, 녹화를 시작하지 않았습니다.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>디스크 여유 공간이 부족합니다.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>디스크 여유 공간 제한</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>디스크 여유 공간이 충분하지 않아서, 녹화가 중단됐습니다.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>No filemanager found.</source>
        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
        <translation>파일탐색기가 없습니다.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>파일탐색기를 설치해 주세요.</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>소스코드</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>홈페이지</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>번역</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>후원하기</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow_wl</name>
    <message>
        <source>Sourcecode</source>
        <translation>소스코드</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>홈페이지</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>번역</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>후원하기</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>파일탐색기가 없습니다.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>파일탐색기를 설치해 주세요.</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>1개 이상의 장치 선택</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher_wl</name>
    <message>
        <source>Select one or more devices</source>
        <translation>1개 이상의 장치 선택</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>영역</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise_wl</name>
    <message>
        <source>Area</source>
        <translation>영역</translation>
    </message>
</context>
<context>
    <name>QvkSnapshot</name>
    <message>
        <source>No filemanager found.</source>
        <translation>파일탐색기가 없습니다.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>파일탐색기를 설치해 주세요.</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>시작</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>중지</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>일시정지</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>계속하기</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>종료</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>카메라</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>확대</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>시작</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>중지</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>일시정지</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>계속하기</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>종료</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>카메라</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>확대</translation>
    </message>
</context>
<context>
    <name>QvkWASAPIController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>1개 이상의 장치 선택</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>대화창</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>좌우 뒤집기</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>상하 뒤집기</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>반전</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>회색</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>흑백</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>창틀 제거</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>카메라 설정</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>영역</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>초기화</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>확대</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>카운트다운</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>영상 크기:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>디스크 여유 공간:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>정보</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>녹화 시간:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>음성</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>프레임 수</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>영상 코덱</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>포맷</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>음성 코덱</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>마우스 커서 녹화하지 않기</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>시</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>분</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>타이머 시작</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>녹화 후 중지</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>시간</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>분</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>초</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>영상 경로</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>디스크 여유 공간 제한</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>시스템 트레이에 표시하기</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>몇 초 후 녹화 시작</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>업데이트 찾기</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>도움말</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>영상</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>사용가능</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>사용불가</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>시작</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>중지</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>일시정지</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>계속하기</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>재생</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>폴더</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>카메라</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>반전</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>회색</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>마지막 녹화 재생</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>폴더 열기</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>녹화 시작할 때 창 최소화</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>창 최소화로 시작하기</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>좌우 반전</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>상하 반전</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>흑백</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>창틀 제거</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>다음 시작시 모든 설정 초기화</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>이미지의 저작권과 라이선스</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>메가바이트</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>스크린캐스트</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>플레이어</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>로그</translation>
    </message>
    <message>
        <source>Automatically</source>
        <translation>자동으로</translation>
    </message>
    <message>
        <source>Create images of tabs </source>
        <translation>탭 이미지 만들기</translation>
    </message>
    <message>
        <source>License information</source>
        <translation>라이선스 정보</translation>
    </message>
    <message>
        <source>ON</source>
        <translation>ON</translation>
    </message>
    <message>
        <source>OFF</source>
        <translation>OFF</translation>
    </message>
    <message>
        <source>Global keyboard shortcuts</source>
        <translation>전역 키보드 단축키</translation>
    </message>
    <message>
        <source>Assigned shortcut keys.</source>
        <translation>할당된 단축키.</translation>
    </message>
    <message>
        <source>Keyboard shortcut not assigned or assigned more than once.</source>
        <translation>키보드 단축키가 할당되지 않았거나, 2개 이상 할당됨.</translation>
    </message>
    <message>
        <source>If it shows assigned but does not work, it is being used by another program.</source>
        <translation>할당된 것으로 표시되지만 작동하지 않는다면, 다른 프로그램에서 사용 중인 것입니다.</translation>
    </message>
    <message>
        <source>Snapshot</source>
        <translation>스냅샷</translation>
    </message>
    <message>
        <source>Imagepath</source>
        <translation>이미지경로</translation>
    </message>
    <message>
        <source>Hide this window</source>
        <translation>이 창 숨기기</translation>
    </message>
    <message>
        <source>Seconds wait before recording</source>
        <translation>몇 초 후 녹화 시작</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>창</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>전체화면</translation>
    </message>
</context>
<context>
    <name>formMainWindow_wl</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>이미지의 저작권과 라이선스</translation>
    </message>
    <message>
        <source>Create images of tabs </source>
        <translation>탭 이미지 만들기</translation>
    </message>
    <message>
        <source>License information</source>
        <translation>라이선스 정보</translation>
    </message>
    <message>
        <source>ON</source>
        <translation>ON</translation>
    </message>
    <message>
        <source>OFF</source>
        <translation>OFF</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>녹화 시간:</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>영상 크기:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>디스크 여유 공간:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>정보</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>창</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>전체화면</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>영역</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>영상 코덱</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>프레임 수</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>포맷</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>사용가능</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>사용불가</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>시작</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>중지</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>폴더</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>마우스 커서 녹화하지 않기</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>음성 코덱</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>영상 경로</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>카운트다운</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>도움말</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>반전</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>회색</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>흑백</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>카메라</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>상하 뒤집기</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>좌우 뒤집기</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>창틀 제거</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>몇 초 후 녹화 시작</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>초기화</translation>
    </message>
    <message>
        <source>Hide this window</source>
        <translation>이 창 숨기기</translation>
    </message>
    <message>
        <source>Seconds wait before recording</source>
        <translation>몇 초 후 녹화 시작</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>이미지의 저작권과 라이선스</translation>
    </message>
</context>
<context>
    <name>playerGST</name>
    <message>
        <source>Play</source>
        <translation>재생</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>일시정지</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>중지</translation>
    </message>
</context>
</TS>